==> lazy_image_style-8.x-1.5.tar.gz: lazy_image_style/src/LazyImageStyleHelper.php <==
<?php

namespace Drupal\lazy_image_style;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\image\ImageStyleInterface;
use Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface;

/**
 * LazyImageStyleHelper service.
 */
class LazyImageStyleHelper {

  CONST TMP_BASE64_IMAGE = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mNkYAAAAAYAAjCB0C8AAAAASUVORK5CYII=";

  /**
   * The lazy_image_style ImmutableConfig.
   *
   * @var array
   */
  protected $settings;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The MIME type guesser.
   *
   * @var \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface
   */
  protected $mimeTypeGuesser;

  /**
   * The image style storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $imageStyleStorage;

  /**
   * Constructs a lazyimagestylehelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface $mimeTypeGuesser
   *   The MIME type guesser.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    ConfigFactoryInterface $config_factory,
    MimeTypeGuesserInterface $mimeTypeGuesser
  ) {

    $this->configFactory = $config_factory;
    $this->mimeTypeGuesser = $mimeTypeGuesser;

    $this->imageStyleStorage = $entity_type_manager->getStorage('image_style');
  }

  /**
   * Rebuild image render array for lazy load.
   */
  public function rebuild(&$variables) {
    // Check use lazy image for current style.
    if (!$this->useLazyLoad($variables['style_name'])) {
      return;
    }

    // Move source uri to data-src attribute.
    $variables['image']['#attributes']['data-src'] = file_url_transform_relative($variables['image']['#uri']);

    // Changed theme render if using template_placeholder.
    if ($this->getConfigValue('lazy_style') == 'template_placeholder') {
      unset($variables['image']['#uri']);
      $variables['image']['#theme'] = 'lazy_image_tmp';
      return;
    }

    // Set tmp url.
    $variables['image']['#uri'] = $this->getTmpUrl($variables['uri']);

    // Add blue effect.
    if ($this->getConfigValue('use_blue')) {
      $variables['image']['#attributes']['class'][] = 'blue';
    }

    $variables['#attached'] = $this->addAttachments(isset($variables['#attached']) ? $variables['#attached'] : []);
  }

  /**
   * Return array attachments.
   *
   * @param array $attached
   *   Attached array.
   * @return array
   *   New attached array.
   */
  public function addAttachments($attached = []) {
    $attached['library'][] = 'lazy_image_style/main';
    $attached['drupalSettings']['lazy_image_style'] = [
      'offset' => $this->getConfigValue('offset') ?: '100',
      'type' => $this->getConfigValue('type') ?: 'tmp_img',
    ];

    if ($this->getConfigValue('observer')) {
      $attached['library'][] = 'lazy_image_style/observer';
    }

    if ($this->getConfigValue('lazy_style') == 'template_placeholder') {
      $attached['library'][] = 'lazy_image_style/template';
    }

    if ($this->getConfigValue('use_blue')) {
      $attached['library'][] = 'lazy_image_style/blue';
    }

    return $attached;
  }

  /**
   * Return tmp url image.
   *
   * @param $source_uri
   * @return string
   */
  protected function getTmpUrl($source_uri) {
    $lazy_style = $this->getConfigValue('lazy_style');

    if ($lazy_style == 'base64') {
      return self::TMP_BASE64_IMAGE;
    }

    $lazy_image_style = $this
      ->imageStyleStorage
      ->load($lazy_style);

    if ($lazy_image_style instanceof ImageStyleInterface) {
      $tmp_image_uri = $lazy_image_style->buildUri($source_uri);

      // Create derivative if necessary.
      if (!file_exists($tmp_image_uri)) {
        $lazy_image_style->createDerivative($source_uri, $tmp_image_uri);
      }

      $mime = $this->mimeTypeGuesser->guess($tmp_image_uri);
      $base_64_image = base64_encode(file_get_contents($tmp_image_uri));

      return "data:{$mime};base64,{$base_64_image}";
    }

    return self::TMP_BASE64_IMAGE;
  }

  /**
   * The method for replace image style if deleted.
   *
   * @param $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function replaceImageStyle(&$form, FormStateInterface $form_state) {
    $replace_style = empty($form_state->getValue('replacement')) ?
      'base64': $form_state->getValue('replacement');

    $this
      ->configFactory
      ->getEditable('lazy_image_style.settings')
      ->set('lazy_style', $replace_style)
      ->save();
  }

  /**
   * Gets data from lazy_image_style.settings configuration object.
   *
   * @param string $key
   * @return mixed
   *   The data that was requested.
   */
  protected function getConfigValue($key) {
    return $this
      ->configFactory
      ->get('lazy_image_style.settings')
      ->get($key);
  }

  /**
   * Return true if image style use lazy load or false.
   *
   * @param $style_name
   * @return bool
   */
  protected function useLazyLoad($style_name) {
    $used_styles = $this->getConfigValue('use');
    return is_array($used_styles) && array_key_exists($style_name, $used_styles);
  }

}

==> lazy_image_style-8.x-1.7.tar.gz: lazy_image_style/src/LazyImageStyleHelper.php <==
<?php

namespace Drupal\lazy_image_style;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\image\ImageStyleInterface;
use Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface;

/**
 * LazyImageStyleHelper service.
 */
class LazyImageStyleHelper {

  CONST TMP_BASE64_IMAGE = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mNkYAAAAAYAAjCB0C8AAAAASUVORK5CYII=";

  /**
   * The lazy_image_style ImmutableConfig.
   *
   * @var array
   */
  protected $settings;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The MIME type guesser.
   *
   * @var \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface
   */
  protected $mimeTypeGuesser;

  /**
   * The image style storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $imageStyleStorage;

  /**
   * Constructs a lazyimagestylehelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface $mimeTypeGuesser
   *   The MIME type guesser.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    ConfigFactoryInterface $config_factory,
    MimeTypeGuesserInterface $mimeTypeGuesser
  ) {

    $this->configFactory = $config_factory;
    $this->mimeTypeGuesser = $mimeTypeGuesser;

    $this->imageStyleStorage = $entity_type_manager->getStorage('image_style');
  }

  /**
   * Rebuild image render array for lazy load.
   */
  public function rebuild(&$variables) {
    // Check use lazy image for current style.
    if (!$this->useLazyLoad($variables['style_name'])) {
      return;
    }

    // Move source uri to data-src attribute.
    $variables['image']['#attributes']['data-src'] = file_url_transform_relative($variables['image']['#uri']);

    // Changed theme render if using template_placeholder.
    if ($this->getConfigValue('lazy_style') == 'template_placeholder') {
      unset($variables['image']['#uri']);
      $variables['image']['#theme'] = 'lazy_image_tmp';
      return;
    }

    // Set tmp url.
    $variables['image']['#uri'] = $this->getTmpUrl($variables['uri']);

    // Add blue effect.
    if ($this->getConfigValue('use_blue')) {
      $variables['image']['#attributes']['class'][] = 'blue';
    }

    $variables['#attached'] = $this->addAttachments(isset($variables['#attached']) ? $variables['#attached'] : []);
  }

  /**
   * Return array attachments.
   *
   * @param array $attached
   *   Attached array.
   * @return array
   *   New attached array.
   */
  public function addAttachments($attached = []) {
    $attached['library'][] = 'lazy_image_style/main';
    $attached['drupalSettings']['lazy_image_style'] = [
      'offset' => $this->getConfigValue('offset') ?: '100',
      'type' => $this->getConfigValue('type') ?: 'tmp_img',
    ];

    if ($this->getConfigValue('observer')) {
      $attached['library'][] = 'lazy_image_style/observer';
    }

    if ($this->getConfigValue('lazy_style') == 'template_placeholder') {
      $attached['library'][] = 'lazy_image_style/template';
    }

    if ($this->getConfigValue('use_blue')) {
      $attached['library'][] = 'lazy_image_style/blue';
    }

    return $attached;
  }

  /**
   * Return tmp url image.
   *
   * @param $source_uri
   * @return string
   */
  protected function getTmpUrl($source_uri) {
    $lazy_style = $this->getConfigValue('lazy_style');

    if ($lazy_style == 'base64') {
      return self::TMP_BASE64_IMAGE;
    }

    $lazy_image_style = $this
      ->imageStyleStorage
      ->load($lazy_style);

    if ($lazy_image_style instanceof ImageStyleInterface) {
      $tmp_image_uri = $lazy_image_style->buildUri($source_uri);

      // Create derivative if necessary.
      if (!file_exists($tmp_image_uri)) {
        $image_derivative = $lazy_image_style->createDerivative($source_uri, $tmp_image_uri);

        // If the image derivative could not be generated
        // Return tmp base64.
        if (!$image_derivative) {
          return self::TMP_BASE64_IMAGE;
        }
      }

      $mime = $this->mimeTypeGuesser->guess($tmp_image_uri);
      $base_64_image = base64_encode(file_get_contents($tmp_image_uri));

      return "data:{$mime};base64,{$base_64_image}";
    }

    return self::TMP_BASE64_IMAGE;
  }

  /**
   * The method for replace image style if deleted.
   *
   * @param $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function replaceImageStyle(&$form, FormStateInterface $form_state) {
    $replace_style = empty($form_state->getValue('replacement')) ?
      'base64': $form_state->getValue('replacement');

    $this
      ->configFactory
      ->getEditable('lazy_image_style.settings')
      ->set('lazy_style', $replace_style)
      ->save();
  }

  /**
   * Gets data from lazy_image_style.settings configuration object.
   *
   * @param string $key
   * @return mixed
   *   The data that was requested.
   */
  protected function getConfigValue($key) {
    return $this
      ->configFactory
      ->get('lazy_image_style.settings')
      ->get($key);
  }

  /**
   * Return true if image style use lazy load or false.
   *
   * @param $style_name
   * @return bool
   */
  protected function useLazyLoad($style_name) {
    $used_styles = $this->getConfigValue('use');
    return is_array($used_styles) && array_key_exists($style_name, $used_styles);
  }

}
